| Title: | Orthogonal Data Projections with Maximal Skewness |
|---|---|
| Description: | It finds Orthogonal Data Projections with Maximal Skewness. The first data projection in the output is the most skewed among all linear data projections. The second data projection in the output is the most skewed among all data projections orthogonal to the first one, and so on. |
| Authors: | Cinzia Franceschini and Nicola Loperfido |
| Maintainer: | Cinzia Franceschini <[email protected]> |
| License: | GPL-2 |
| Version: | 1.1 |
| Built: | 2026-05-20 07:56:50 UTC |
| Source: | https://github.com/cran/MaxSkew |
Finds Orthogonal Data Projections with Maximal Skewness
Package: MaxSkew
Type: Package
Title: Orthogonal Data Projections with Maximal Skewness
Version: 1.1
Date: 2017-05-02
Author: Cinzia Franceschini, Nicola Loperfido
Maintainer: Cinzia Franceschini <[email protected]>
Description: It finds Orthogonal Data Projections with Maximal Skewness. The first data projection in the output is the most skewed among all linear data projections. The second data projection in the output is the most skewed among all data projections orthogonal to the first one, and so on.
License: GPL-2
Cinzia Franceschini and Nicola Loperfido
de Lathauwer L., de Moor B.and Vandewalle J. (2000). Onthebestrank-1andrank-(R_1,R_2,...R_N) approximation of high-order tensors. SIAM Jour. Matrix Ana. Appl. 21, 1324-1342.
Loperfido, N. (2010). Canonical Transformations of Skew-Normal Variates. Test 19, 146-165.
Loperfido, N. (2013). Skewness and the Linear Discriminant Function. Statistics and Probability Letters 83, 93-99.
Malkovich, J.F. and Afifi, A.A. (1973). On Tests for Multivariate Normality. J. Amer. Statist. Ass. 68, 176-179
## Example 1. Run MaxSkew on the iris data data(iris) iris<-data.matrix(iris) #returns the matrix obtained by converting the data frame to numeric mode MaxSkew(iris[,1:3],5,2,FALSE) # matrix whose columns are the two projections with maximal skewness MaxSkew(iris[,1:2],5,1,FALSE) #projection with maximal skewness of the first two variables #MaxSkewBiv(iris[,1],iris[,2]) #obtains the same of MaxSkew(iris[,1:2],5,1) ## Example 2. Run MaxSkew on the OLYMPIC_DECATHLON_2016 data data(OLYMPIC_DECATHLON_2016) OLYMPIC_DECATHLON_2016_matrix<-data.matrix(OLYMPIC_DECATHLON_2016) #returns a data matrix MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,TRUE) #it returns also the scatterplot MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,FALSE)#as in example 1 OLYMPIC_DECATHLON_2016_projections<-MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,FALSE) plot(OLYMPIC_DECATHLON_2016_projections) #scatterplot of the first two projections ##install.packages("calibrate") ##library(calibrate) ##textxy(OLYMPIC_DECATHLON_2016_projections[,1],OLYMPIC_DECATHLON_2016_projections[,2], ##OLYMPIC_DECATHLON_2016$ATHLETE,offset=0.5)## Example 1. Run MaxSkew on the iris data data(iris) iris<-data.matrix(iris) #returns the matrix obtained by converting the data frame to numeric mode MaxSkew(iris[,1:3],5,2,FALSE) # matrix whose columns are the two projections with maximal skewness MaxSkew(iris[,1:2],5,1,FALSE) #projection with maximal skewness of the first two variables #MaxSkewBiv(iris[,1],iris[,2]) #obtains the same of MaxSkew(iris[,1:2],5,1) ## Example 2. Run MaxSkew on the OLYMPIC_DECATHLON_2016 data data(OLYMPIC_DECATHLON_2016) OLYMPIC_DECATHLON_2016_matrix<-data.matrix(OLYMPIC_DECATHLON_2016) #returns a data matrix MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,TRUE) #it returns also the scatterplot MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,FALSE)#as in example 1 OLYMPIC_DECATHLON_2016_projections<-MaxSkew(OLYMPIC_DECATHLON_2016_matrix[,4:13],10,2,FALSE) plot(OLYMPIC_DECATHLON_2016_projections) #scatterplot of the first two projections ##install.packages("calibrate") ##library(calibrate) ##textxy(OLYMPIC_DECATHLON_2016_projections[,1],OLYMPIC_DECATHLON_2016_projections[,2], ##OLYMPIC_DECATHLON_2016$ATHLETE,offset=0.5)
Finds Orthogonal Data Projections with Maximal Skewness for Bivariate Random Vectors
.MaxSkewBiv(x, y).MaxSkewBiv(x, y)
x |
it is a numerical variable |
y |
it is a numerical variable |
.projectionBIV |
Vector of projected data when the original data are bivariate. The user can obtain it by writing ".projectionBIV", and he can obtain a scatterplot of the projection by writing plot(.projectionBIV). |
Cinzia Franceschini and Nicola Loperfido
de Lathauwer L., de Moor B.and Vandewalle J. (2000). Onthebestrank-1andrank-(R_1,R_2,...R_N) approximation of high-order tensors. SIAM Jour. Matrix Ana. Appl. 21, 1324-1342.
Loperfido, N. (2010). Canonical Transformations of Skew-Normal Variates. Test 19, 146-165.
Loperfido, N. (2013). Skewness and the Linear Discriminant Function. Statistics and Probability Letters 83, 93-99.
Malkovich, J.F. and Afifi, A.A. (1973). On Tests for Multivariate Normality. J. Amer. Statist. Ass. 68, 176-179
Finds Orthogonal Data Projections with Maximal Skewness for Trivariate Random Vectors
.MaxSkewThree(data, iterations).MaxSkewThree(data, iterations)
data |
Data matrix where rows and columns represent units and variables. |
iterations |
Number of required iterations. |
It is an internal function called by MaxSkew
Cinzia Franceschini and Nicola Loperfido
de Lathauwer L., de Moor B.and Vandewalle J. (2000). Onthebestrank-1andrank-(R_1,R_2,...R_N) approximation of high-order tensors. SIAM Jour. Matrix Ana. Appl. 21, 1324-1342.
Loperfido, N. (2010). Canonical Transformations of Skew-Normal Variates. Test 19, 146-165.
Loperfido, N. (2013). Skewness and the Linear Discriminant Function. Statistics and Probability Letters 83, 93-99.
Malkovich, J.F. and Afifi, A.A. (1973). On Tests for Multivariate Normality. J. Amer. Statist. Ass. 68, 176-179
Finds Orthogonal Data Projections with Maximal Skewness
MaxSkew(data, iterations, components, plot)MaxSkew(data, iterations, components, plot)
data |
Data matrix where rows and columns represent units and variables. |
iterations |
It is a positive integer |
components |
Number of orthogonal projections maximizing skewness. It is a positive integer smaller than the number of variables. |
plot |
Dichotomous variable: TRUE/FALSE. If plot is set equal to TRUE (FALSE) the scatterplot appears (does not appear) in the output. |
projectionmatrix |
Matrix of projected data. The i-th row represents the i-th unit, while the j-th column represents the j-th projection. |
pairs(projectionmatrix[, 2:i], labels=values, main="Projections")
|
It is the multiple scatterplot of the projections maximizing skewness. |
.projectionBIV |
Vector of projected data when the original data are bivariate.The user can obtain a scatterplot of the projection by writing plot(.projectionBIV) |
Cinzia Franceschini and Nicola Loperfido
de Lathauwer L., de Moor B.and Vandewalle J. (2000). Onthebestrank-1andrank-(R_1,R_2,...R_N) approximation of high-order tensors. SIAM Jour. Matrix Ana. Appl. 21, 1324-1342.
Loperfido, N. (2010). Canonical Transformations of Skew-Normal Variates. Test 19, 146-165.
Loperfido, N. (2013). Skewness and the Linear Discriminant Function. Statistics and Probability Letters 83, 93-99.
Malkovich, J.F. and Afifi, A.A. (1973). On Tests for Multivariate Normality. J. Amer. Statist. Ass. 68, 176-179
Results of the athletes competing in the decathlon at the Games of the XXXI Olympiad (Rio de Janeiro, Brazil, year 2016). The dataset contains the points scored in each event by the 23 decathletes who who completed the dacathlons, together with their names and nationalities. It is freely available at www.iaaf.org, the official website of the IAAF (International Association of Athletics Federations).
data("OLYMPIC_DECATHLON_2016")data("OLYMPIC_DECATHLON_2016")
A data frame with 23 observations on the following 13 variables.
OSa numeric vector. Athletes' ranking.
ATHLETEa factor with levels Adam SebastianHELCELET Akihiko NAKAMURA Arthur ABELE Ashton EATON Bastien AUZEIL Cedric DUBLER Damian WARNER Dominik DISTELBERGER Jeremy TAIWO Kai KAZMIREK Karl Robert SALURI Keisuke USHIRO Kevin MAYER Kurt FELIX Larbi BOURRADA Leonel SUAREZ Lindon VICTOR Luiz Alberto DE ARAUJO Pau TONNESEN Pawel WIESIOLEK Thomas VAN DER PLAETSEN Yordani GARCIA Zach ZIEMEK
COUNTRYa factor with levels ALG AUS AUT BEL BRA CAN CUB CZE ESP EST FRA GER GRN JPN POL USA
a numeric vector. Points scored in the one hundred metres.
LONG.JUMPa numeric vector. Points scored in the long jump.
SHOT.PUTa numeric vector. Points scored in the shot put.
HIGH.JUMPa numeric vector. Points scored in the high jump.
a numeric vector. Points scored in the four hundred metres.
a numeric vector. Points scored in the one hundred and ten metres hurdles.
DISCUS.THROWa numeric vector. Points scored in the discus throw.
POLE.VAULTa numeric vector. Points scored in the pole vault.
JAVELIN.THROWa numeric vector. Points scored in the javelin throw.
X1500.METRESa numeric vector. Points scored in the one thousand and five hundred metres.
www.iaaf.org
data(OLYMPIC_DECATHLON_2016) ## maybe str(OLYMPIC_DECATHLON_2016) ; plot(OLYMPIC_DECATHLON_2016) ...data(OLYMPIC_DECATHLON_2016) ## maybe str(OLYMPIC_DECATHLON_2016) ; plot(OLYMPIC_DECATHLON_2016) ...